/**
 * @category Dashboard
 * @since 0.2.0
 */
export interface Host {
    /**
     * Opens an external URL with the system default browser.
     * @since 0.2.0
     *
     * ```typescript
     * ddClient.host.openExternal("https://docker.com");
     * ```
     * @param url The URL the browser will open (must have the protocol `http` or `https`).
     */
    openExternal(url: string): void;
    /**
     * Returns a string identifying the operating system platform. See https://nodejs.org/api/os.html#osplatform
     * @since 0.2.2
     */
    platform: string;
    /**
     * Returns the operating system CPU architecture. See https://nodejs.org/api/os.html#osarch
     * @since 0.2.2
     */
    arch: string;
    /**
     * Returns the host name of the operating system. See https://nodejs.org/api/os.html#oshostname
     * @since 0.2.2
     */
    hostname: string;
}
